/* pformat
 * 1997/10/24
 * Jeff Weeks
 *
 * pformat will format a disk according to the Poly One file system
 * specifications.  Currently it prompts for user input at run time
 * but will soon support command line arguments and default parameters.
 * Also, as mentioned occasionally in the source, ideally certain inputs
 * would be restricted to certain values.  This currently is not
 * implemented, but will be in the GUI version.  In other words, this
 * is a very limited version, but will remain as is for a while.  It
 * suffices for me until a workable kernel is intact.
 *
 * If you're interested in inputs, I'll explain them a bit.  First of all,
 * the drive is a BIOS drive number, not a DOS drive letter.  So, 0 is
 * drive A, 1 is drive B, 128 is C and 129 is D.  Personally, unless you're
 * slightly psychotic, I'd advice you only use this program on floppies.
 *
 * The block size is just that;  The size, in bytes, of a block;  The
 * smallest allocatable unit of the Poly One file system.  Smaller block
 * sizes will, no doubt, use disk space more effeciently, however, larger
 * block sizes will, most likely, be faster.  Typical sizes are 1K, 2K,
 * or 4K.  Choose according to your tastes.  I recommend 1K for floppies due
 * to their limited disk space.
 *
 * The reserved inodes question is asking you how many inodes you wish to
 * preallocate.  When this number runs out, the same number of inodes will
 * be allocated again.  You should use a number which allows the inodes to
 * completely fill a block.  For example, if you used 1K blocks, you should
 * reserve inodes by multiples of 8 (sence 8 inodes will fit in 1K).  For a
 * floppy I usually reserve 16 or 32 inodes.
 */
#include <iostream.h>
#include <assert.h>
#include <stdlib.h>
#include <conio.h>
#include <stdio.h>
#include <ctype.h>
#include <bios.h>

#include "pfs.h"

PFS pfs;

int main(void) {
  char drive[5];     // used to input the drive to use
  int drive_num;     // to convert the above to a real number
  int block_log,     // the block size in "logarithm form"
      block_size,    // the actual block size
      num_inodes;    // the number of inodes to reserve

  // Just a check to see that my structures aren't screwed :)
  assert(sizeof(pfs.super) == 1024);
  assert(sizeof(pfs.inode) == 128);

  // get the drive number to format
  cout << "Format which drive? ";
  cin  >> drive;

  // Convert the drive string to a number...
  drive_num = atoi(drive);
  // ...and prompt if we're formatting a hard drive (ie: the user is nuts)
  if((drive_num & 7)) {
    cout << "Are you sure you want to format a hard drive!?!?\n";
    if(toupper(getch()) != 'Y') exit(1);
  }

  // Clear the screen and set the drive (which will display vital info)
  clrscr();
  pfs.set_drive(drive_num);

  // Ask for a block size, and convert the responce to a real block size
  cout << "Enter a block size log (0 = 1024, 1 = 2048, 2 = 4096, 3 = 8192, etc) ";
  cin >> block_log;
  block_size = (1024 << block_log);

  // Lastly, ask how many inodes to reserve
  cout << "Reserve how many inodes? ";
  cin >> num_inodes;

  // Now, with the user's input, we'll format the drive
  pfs.format(block_size, num_inodes);
  getch();
  return 0;
}
